﻿using System;
using System.IO;
using System.Collections.Generic;

using SDX.Core;
using SDX.Payload;

public class LocalizationMod : ModScript
{

    public override void OnPreGameStarted()
    {
        
    }

    public override void OnPostGameStarted()
    {
        LoadCustomStrings();
        DumpLocalizationData();
    }

    public static string StringsFilePath
    {
        get
        {
            return Path.Combine(PathHelper.SDXDataDir, "English.txt");
        }
    }

    private void DumpLocalizationData()
    {
        string outputPath = Path.Combine(PathHelper.SDXDataDir, "LocalizationDump.txt");
        using (FileStream fs = new FileStream(outputPath, FileMode.Create, FileAccess.Write))
        {
            using (StreamWriter sw = new StreamWriter(fs))
            {
                foreach(KeyValuePair<string, string[]> rowKV in Localization.rowLookupTable)
                {
                    sw.Write(rowKV.Key+",");
                    foreach(string str in rowKV.Value)
                    {
                        sw.Write(str + ",");
                    }
                    sw.Write('\n');
                }
            }
        }
    }

    private void LoadCustomStrings()
    {
        if (File.Exists(StringsFilePath))
        {
            ModEngine.Log("Loading custom strings...");
            int count = 0;

            using (FileStream fs = new FileStream(StringsFilePath, FileMode.Open, FileAccess.Read))
            {
                using (StreamReader sr = new StreamReader(fs))
                {
                    string line;
                    while ((line = sr.ReadLine()) != null)
                    {
                        if (line.StartsWith("#")) continue;
                        string[] parts = line.Split('=');
                        if (parts.Length != 2)
                            continue;
                        SetItem(parts[0].Trim(), parts[1].Trim());
                        count++;
                    }
                }
            }

            ModEngine.Log(String.Format("Loaded {0} strings.", count));
        }
        else
        {
            ModEngine.Log("No custom strings file");
        }
    }

    public void SetItem(string key, string value)
    {
        Logging.Log("Localization::SetItem('" + key + "', '" + value + "')", Logging.LogType.Log);
        //progression,Skill,,Do more damage with bows and crossbows.Gain skill by using items from this group.,,
        string[] strArray = new string[]
        {
            "","SDX","",value,""
        };
        if (Localization.rowLookupTable.ContainsKey(key))
        {
            Logging.Log("Found duplicate string: " + key, Logging.LogType.Log);
        }
        else
        {
            Localization.rowLookupTable.Add(key, strArray);
        }
        Localization.lookupTable.Add(key, value);
        
    }

}